Installation — snptools version 1.0.8 documentation

# Installation

To install snplib, follow the steps below.

## The easiest way to install:

You can install snptools via pip from (https://pypi.org/project/snplib/)

    pip install snplib

## Another method is more complicated:

Clone the repository into your project directory:

    git clone https://github.com/IgorekLoschinin/snptools.git

Set dependencies:

    cd snptools
    python -m pip install -r requirements.txt

Use SNPlib:

    import snplib